/**
 * Checks if a given string is a valid IPv4 address.
 *
 * @param {string|null|undefined} ipAddress - The IP address to validate.
 * @returns {boolean} True if the IP address is valid, false otherwise.
 * @throws {TypeError} Throws a TypeError if ipAddress is not a string.
 */
const isValidIpAddress = (ipAddress: string | null | undefined): boolean => {
  if (typeof ipAddress !== "string") {
    throw new TypeError("ipAddress must be a string");
  }

  const ipAddressRegex =
    /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
  return ipAddressRegex.test(ipAddress);
};

export { isValidIpAddress };
