/**
 * Checks if a given string is a valid JSON.
 *
 * @param {string} json - The string to be checked.
 * @returns {boolean} - Returns `true` if the string is valid JSON, `false` otherwise.
 */
const isValidJson = (json: string): boolean => {
  try {
    // Check if json is not a string
    if (typeof json !== "string") {
      return false;
    }

    // Parse the string to JSON
    JSON.parse(json);
  } catch (e) {
    // If parsing fails, return false
    return false;
  }

  // If parsing was successful, return true
  return true;
};

export { isValidJson };
