const defaultAllowed = ["https:", "http:"];
const allowedLocalHosts = ["localhost", "127.0.0.1"];

/**
 * Check if a given string is a valid URL.
 * @param url The string to be checked.
 * @param allowedProtocols An optional array of allowed protocols.
 * @returns {boolean} Returns true if the url is a valid URL, false otherwise.
 * @throws {TypeError} Throws a TypeError if url is not a string.
 */
const isValidUrl = (url: string, allowedProtocols?: string[]): boolean => {
  try {
    if (typeof url !== "string") {
      throw new TypeError("url must be a string");
    }

    if (url.length === 0) return false;

    if (allowedLocalHosts.includes(url)) return true;

    //check if url is without protocol, example: example.com
    if (url.includes(".") && !url.includes("://"))
      return isValidUrl(`http://${url}`);

    const fccUrl = new URL(url);

    const mapProtocols =
      allowedProtocols?.map((p) => (p.endsWith(":") ? p : `${p}:`)) ?? [];

    const checkProtocols = [...defaultAllowed, ...mapProtocols].map((p) =>
      p.toLowerCase()
    );

    const check =
      checkProtocols.includes(fccUrl.protocol) ||
      checkProtocols.includes(fccUrl.protocol.toLowerCase());

    if (check) return true;
    return false;
  } catch (error) {
    return false;
  }
};

export { isValidUrl };
