/**
 * Creates a new Date object with the specified hour and minute.
 *
 * @param {number} hours - The hour to set for the new Date
 * @param {number} minutes - The minute to set for the new Date
 * @return {Date} The new Date object with the specified hour and minute
 *
 * @example
 * // creates a Date object with the hour 12 and minute 30
 *
 * // if current time is 12:30
 *
 * const newDate = createDate(12, 30);
 * console.log(newDate);
 * @result Wed Dec 31 2022 12:30:00
 */
const createDate = (hours: number, minutes: number): Date => {
  const date = new Date();
  date.setHours(hours, minutes, 0, 0);
  return date;
};

/**
 * Creates a new Date object that represents a specific date and time in the future, based on the current date and time.
 *
 * @param {number} offsetInDays - The number of days to offset from the current date and time.
 * @return {Date} - The new Date object representing the future date and time.
 *
 * @example
 * // creates a Date object that is 5 days from now
 * const newDate = createDateFromNowWithOffset(5);
 * console.log(newDate);
 *
 * @result Wed Dec 31 2022 12:30:00
 */

const MS_PER_DAY = 1000 * 60 * 60 * 24;
/**
 * Creates a new Date object that represents a specific date and time in the future, based on the current date and time.
 *
 * @param {number} offsetInDays - The number of days to offset from the current date and time.
 * @return {Date} - The new Date object representing the future date and time.
 */
const createDateFromNowWithOffset = (offsetInDays: number): Date => {
  const currentDate = new Date();
  const offsetInMilliseconds = offsetInDays * MS_PER_DAY;
  const newDate = new Date(currentDate.getTime() + offsetInMilliseconds);
  return newDate;
};

export { createDate, createDateFromNowWithOffset };
