import fs, { existsSync } from "fs-extra";

/**
 * Deletes the specified directory if it exists.
 *
 * @param {string} directoryPath - The path of the directory to be deleted
 * @return {boolean} Returns true if the directory is successfully deleted, otherwise false
 */
const fsDeleteDirectory = async (directoryPath: string) => {
  if (!existsSync(directoryPath)) return true;
  await fs.rm(directoryPath, { recursive: true, force: true });
  return true;
};

/**
 * Deletes a file at the specified filePath.
 *
 * @param {string} filePath - The path of the file to be deleted.
 * @return {Promise<boolean>} A Promise that resolves to true if the file is successfully deleted.
 */
const fsDeleteFile = async (filePath: string): Promise<boolean> =>
  fs.promises.rm(filePath, { force: true }).then(
    () => true,
    () => true
  );

export { fsDeleteDirectory, fsDeleteFile };
